#
# spec file for package libfsext
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libfsext1
Name:           libfsext
Version:        20240501
Release:        1.5
Summary:        Library and tools to access the Extended File System
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libfsext
Source:         https://github.com/libyal/libfsext/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libfsext/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfcache) >= 20240414
BuildRequires:  pkgconfig(libfdata) >= 20240415
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libhmac) >= 20240417
BuildRequires:  pkgconfig(libuna) >= 20240414
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libfsext is a library to access the Extended File System (ext).

Read-only supported ext formats:

* ext2 (version 2)
* ext3 (version 3)
* ext4 (version 4)

Supported ext format features:

* ext4 inline data

Unsupported ext format features:

* ext (version 1)
* compression
* encryption

%package -n %lname
Summary:        Library to access the Extended File System (ext)
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libfsext is a library to access the Extended File System (ext).

Read-only supported ext formats:

* ext2 (version 2)
* ext3 (version 3)
* ext4 (version 4)

Supported ext format features:

* ext4 inline data

Unsupported ext format features:

* ext (version 1)
* compression
* encryption

%package tools
Summary:        Tools to access the Extended File System (ext)
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities
Requires:       %lname = %version

%description tools
Tools to access the Extended File System.  See libfsext for additional details.

%package devel
Summary:        Development files for libfsext, Extended File System (ext) library
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libfsext is a library to access the extended file system (ext) format.  see libfsext for details.

This subpackage contains libraries and header files for developing
applications that want to make use of libfsext.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* %buildroot/
find "%buildroot" -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libfsext.so.*

%files -n %name-tools
%license COPYING*
%_bindir/fsext*
%_mandir/man1/fsext*.1*

%files -n %name-devel
%license COPYING*
%_includedir/libfsext.h
%_includedir/libfsext/
%_libdir/libfsext.so
%_libdir/pkgconfig/libfsext.pc
%_mandir/man3/libfsext.3*

%files %python_files
%license COPYING*
%python_sitearch/pyfsext.so

%changelog
* Wed May  1 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240501
  * Perform CRC check on the superblock
* Sat Mar  2 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240301
  * Support for EXT2_FEATURE_COMPAT_DIR_INDEX,
    EXT4_FEATURE_COMPAT_FAST_COMMIT,
    EXT4_FEATURE_COMPAT_STABLE_INODES,
    EXT4_FEATURE_COMPAT_ORPHAN_FILE,
    EXT4_FEATURE_RO_COMPAT_ORPHAN_PRESENT
* Mon Feb 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240219
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Thu Nov 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231129
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Sat Jun  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230603
  * Support nameless extended attributes
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Tue Aug 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220829
  * Unspecified updates to the API
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220822
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sat Jan 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220112
  * Updates to Python bindings and tools.
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210721
  * Python binding updates
  * Improved extended attribute support
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210522
  * No changelog was provided
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210513 (3f4411ea)
  * No changelog was provided
- Add system-libs.patch
* Fri Nov 13 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- initial package
  * version 20201107
